@@ -32,7 +32,7 @@ def main():
         table.add_row(str(i), file.name)
 
     console.print(table)
-    input_res = input("Delete files? \ny/n \n")
+    input_res = input("Delete files? [y/N]: ")
 
     if input_res.lower() == "y":
         with Progress() as progress:
